@@ -23,15 +23,23 @@
 #include <grpc/support/sync.h>
 #include <grpc/support/thd.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct gts_shared_resource {
   gpr_thd_id thread_id;
-  grpc_channel *channel;
-  grpc_completion_queue *cq;
+  grpc_channel* channel;
+  grpc_completion_queue* cq;
   gpr_mu mu;
 } gts_shared_resource;
 
 /* This method returns the address of gts_shared_resource object shared by all
  *    TSI handshakes. */
-gts_shared_resource *gts_get_shared_resource(void);
+gts_shared_resource* gts_get_shared_resource(void);
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* GRPC_CORE_TSI_GTS_TRANSPORT_SECURITY_H */
